@@ -106,7 +106,7 @@ html_encode_entities (const gchar *input, guint len, guint *encoded_len_return)
 			/* Default case, just copy. */
 			*out++ = uc;
 		} else {
-			char buf[10], *ptr;
+			gchar buf[10], *ptr;
 
 			g_snprintf(buf, 9, "&#%d;", uc);
 
@@ -164,10 +164,10 @@ html_engine_save_encode_string (HTMLEngineSaveState *state,
 
 gboolean
 html_engine_save_output_stringv (HTMLEngineSaveState *state,
-				 const char *format,
+				 const gchar *format,
 				 va_list ap)
 {
-	char *string;
+	gchar *string;
 	gboolean retval;
 
 	string = g_strdup_vprintf (format, ap);
@@ -196,7 +196,7 @@ html_engine_save_output_string (HTMLEngineSaveState *state,
 }
 
 gboolean
-html_engine_save_output_buffer (HTMLEngineSaveState *state, const gchar *buffer, int bytes)
+html_engine_save_output_buffer (HTMLEngineSaveState *state, const gchar *buffer, gint bytes)
 {
 	if (bytes == -1)
 		bytes = strlen (buffer);
@@ -285,14 +285,14 @@ write_header (HTMLEngineSaveState *state)
 
 	html_engine_clear_all_class_data (state->engine);
 	/* Preface.  */
-	if (! html_engine_save_output_string
-	            (state,
+	if (!html_engine_save_output_string
+		    (state,
 		     "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 TRANSITIONAL//EN\">\n"
 		     "<HTML>\n"))
 		return FALSE;
 
 	/* Header start.  FIXME: `GENERATOR' string?  */
-	if (! html_engine_save_output_string
+	if (!html_engine_save_output_string
 		     (state,
 		      "<HEAD>\n"
 		      "  <META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; CHARSET=UTF-8\">\n"
@@ -303,14 +303,14 @@ write_header (HTMLEngineSaveState *state)
 	if (state->engine->title != NULL
 	    && state->engine->title->str != NULL
 	    && state->engine->title->str[0] != '\0') {
-		if (! html_engine_save_delims_and_vals (state,
+		if (!html_engine_save_delims_and_vals (state,
 				"  <TITLE>", state->engine->title->str,
 				"</TITLE>\n", NULL))
 			return FALSE;
 	}
 
 	/* End of header.  */
-	if (! html_engine_save_output_string (state, "</HEAD>\n"))
+	if (!html_engine_save_output_string (state, "</HEAD>\n"))
 		return FALSE;
 
 	/* Start of body.  */
@@ -325,7 +325,7 @@ write_header (HTMLEngineSaveState *state)
 static gboolean
 write_end (HTMLEngineSaveState *state)
 {
-	if (! html_engine_save_output_string (state, "</BODY>\n</HTML>\n"))
+	if (!html_engine_save_output_string (state, "</BODY>\n</HTML>\n"))
 		return FALSE;
 
 	html_engine_clear_all_class_data (state->engine);
@@ -355,14 +355,14 @@ html_engine_save (HTMLEngine *engine,
 	state.user_data = user_data;
 	state.last_level = 0;
 
-	if (! write_header (&state))
+	if (!write_header (&state))
 		return FALSE;
 
 	html_object_save (engine->clue, &state);
 	if (state.error)
 		return FALSE;
 
-	if (! write_end (&state))
+	if (!write_end (&state))
 		return FALSE;
 
 	return TRUE;
@@ -409,11 +409,11 @@ html_engine_save_buffer_receiver (const HTMLEngine *engine,
 	return TRUE;
 }
 
-char *
+gchar *
 html_engine_save_buffer_free (HTMLEngineSaveState *state, gboolean free_string)
 {
 	GString *string;
-	char *rv = NULL;
+	gchar *rv = NULL;
 
 	g_return_val_if_fail (state != NULL, NULL);
 	string = (GString *)state->user_data;
@@ -438,7 +438,7 @@ html_engine_save_buffer_peek_text (HTMLEngineSaveState *state)
 	return (guchar *) string->str;
 }
 
-int
+gint
 html_engine_save_buffer_peek_text_bytes (HTMLEngineSaveState *state)
 {
 	GString *string;
